==> open-xchange-core_7.6.2.orig.tar.bz2: open-xchange-core-7.6.2/com.openexchange.server/src/com/openexchange/ajax/requesthandler/osgi/OSGiAJAXResultDecoratorRegistry.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.ajax.requesthandler.osgi;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import com.openexchange.ajax.requesthandler.AJAXResultDecorator;
import com.openexchange.ajax.requesthandler.AJAXResultDecoratorRegistry;

/**
 * {@link OSGiAJAXResultDecoratorRegistry}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class OSGiAJAXResultDecoratorRegistry implements AJAXResultDecoratorRegistry, ServiceTrackerCustomizer<AJAXResultDecorator, AJAXResultDecorator> {

    /**
     * The backing map.
     */
    final ConcurrentMap<String, AJAXResultDecorator> map;

    /**
     * The bundle context.
     */
    private final BundleContext context;

    /**
     * Initializes a new {@link OSGiChatServiceRegistry}.
     */
    public OSGiAJAXResultDecoratorRegistry(final BundleContext context) {
        super();
        this.context = context;
        map = new ConcurrentHashMap<String, AJAXResultDecorator>(8);
    }

    @Override
    public List<AJAXResultDecorator> getDecorators() {
        return new ArrayList<AJAXResultDecorator>(map.values());
    }

    @Override
    public AJAXResultDecorator getDecorator(final String identifier) {
        return map.get(identifier);
    }

    @Override
    public AJAXResultDecorator addingService(final ServiceReference<AJAXResultDecorator> reference) {
        final AJAXResultDecorator service = context.getService(reference);
        if (null == map.putIfAbsent(service.getIdentifier(), service)) {
            return service;
        }
        final org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(OSGiAJAXResultDecoratorRegistry.class);
        logger.warn("Another AJAXResultDecorator is already registered with identifier: {}", service.getIdentifier());
        context.ungetService(reference);
        return null;
    }

    @Override
    public void modifiedService(final ServiceReference<AJAXResultDecorator> reference, final AJAXResultDecorator service) {
        // Nothing to do
    }

    @Override
    public void removedService(final ServiceReference<AJAXResultDecorator> reference, final AJAXResultDecorator service) {
        try {
            map.remove(service.getIdentifier());
        } finally {
            context.ungetService(reference);
        }
    }

}

==> open-xchange-core_7.8.1.orig.tar.bz2: open-xchange-core-7.8.1/com.openexchange.server/src/com/openexchange/ajax/requesthandler/osgi/OSGiAJAXResultDecoratorRegistry.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.ajax.requesthandler.osgi;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import com.openexchange.ajax.requesthandler.AJAXResultDecorator;
import com.openexchange.ajax.requesthandler.AJAXResultDecoratorRegistry;

/**
 * {@link OSGiAJAXResultDecoratorRegistry}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class OSGiAJAXResultDecoratorRegistry implements AJAXResultDecoratorRegistry, ServiceTrackerCustomizer<AJAXResultDecorator, AJAXResultDecorator> {

    /**
     * The backing map.
     */
    final ConcurrentMap<String, AJAXResultDecorator> map;

    /**
     * The bundle context.
     */
    private final BundleContext context;

    /**
     * Initializes a new {@link OSGiChatServiceRegistry}.
     */
    public OSGiAJAXResultDecoratorRegistry(final BundleContext context) {
        super();
        this.context = context;
        map = new ConcurrentHashMap<String, AJAXResultDecorator>(8, 0.9f, 1);
    }

    @Override
    public List<AJAXResultDecorator> getDecorators() {
        return new ArrayList<AJAXResultDecorator>(map.values());
    }

    @Override
    public AJAXResultDecorator getDecorator(final String identifier) {
        return map.get(identifier);
    }

    @Override
    public AJAXResultDecorator addingService(final ServiceReference<AJAXResultDecorator> reference) {
        final AJAXResultDecorator service = context.getService(reference);
        if (null == map.putIfAbsent(service.getIdentifier(), service)) {
            return service;
        }
        final org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(OSGiAJAXResultDecoratorRegistry.class);
        logger.warn("Another AJAXResultDecorator is already registered with identifier: {}", service.getIdentifier());
        context.ungetService(reference);
        return null;
    }

    @Override
    public void modifiedService(final ServiceReference<AJAXResultDecorator> reference, final AJAXResultDecorator service) {
        // Nothing to do
    }

    @Override
    public void removedService(final ServiceReference<AJAXResultDecorator> reference, final AJAXResultDecorator service) {
        try {
            map.remove(service.getIdentifier());
        } finally {
            context.ungetService(reference);
        }
    }

}
